@@ -3,8 +3,8 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2023 Osimis S.A., Belgium
- * Copyright (C) 2024-2024 Orthanc Team SRL, Belgium
- * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2024-2025 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2025 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -86,7 +86,7 @@ namespace OrthancPlugins
     std::string contentType;
 
     if (!Orthanc::MultipartStreamReader::GetMainContentType(contentType, headers) ||
-        contentType != "application/dicom")
+        contentType.find("application/dicom") == std::string::npos)
     {
       throw Orthanc::OrthancException(
         Orthanc::ErrorCode_UnsupportedMediaType,
@@ -247,7 +247,12 @@ namespace OrthancPlugins
     assert(parser_.get() != NULL);
     parser_->CloseStream();
 
-    result_[DICOM_TAG_FAILED_SOP_SEQUENCE.Format()] = failed_;
+    if (failed_.size() > 0)
+    {
+      // new in 1.19: don't include the failed sequence if there are no failures (https://discourse.orthanc-server.org/t/orthanc-dicomweb-stowrs-server-request-response-compatibility/5763)
+      result_[DICOM_TAG_FAILED_SOP_SEQUENCE.Format()] = failed_;
+    }
+
     result_[DICOM_TAG_REFERENCED_SOP_SEQUENCE.Format()] = success_;
     
     std::string answer;
