@@ -3,8 +3,8 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2023 Osimis S.A., Belgium
- * Copyright (C) 2024-2024 Orthanc Team SRL, Belgium
- * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2024-2025 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2025 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -27,23 +27,31 @@
 
 
 bool LocateStudy(OrthancPluginRestOutput* output,
-                 std::string& uri,
+                 std::string& studyOrthancId,
                  std::string& studyInstanceUid,
                  const OrthancPluginHttpRequest* request);
 
 bool LocateSeries(OrthancPluginRestOutput* output,
-                  std::string& uri,
+                  std::string& seriesOrthancId,
                   std::string& studyInstanceUid,
                   std::string& seriesInstanceUid,
                   const OrthancPluginHttpRequest* request);
 
 bool LocateInstance(OrthancPluginRestOutput* output,
-                    std::string& uri,
+                    std::string& instanceOrthancId,
                     std::string& studyInstanceUid,
                     std::string& seriesInstanceUid,
                     std::string& sopInstanceUid,
+                    std::string& transferSyntaxMetadata,
                     const OrthancPluginHttpRequest* request);
 
+bool LocateOneInstance(OrthancPluginRestOutput* output,
+                       std::string& instanceOrthancId,
+                       std::string& studyInstanceUid,
+                       std::string& seriesInstanceUid,
+                       std::string& transferSyntaxMetadata,
+                       const OrthancPluginHttpRequest* request);
+
 void RetrieveDicomStudy(OrthancPluginRestOutput* output,
                         const char* url,
                         const OrthancPluginHttpRequest* request);
@@ -88,22 +96,26 @@ void RetrieveSelectedFrames(OrthancPluginRestOutput* output,
 
 void RetrieveInstanceRendered(OrthancPluginRestOutput* output,
                               const char* url,
-                              const OrthancPluginHttpRequest* request);
+                              const OrthancPluginHttpRequest* request,
+                              bool isThumbnail);
 
 void RetrieveFrameRendered(OrthancPluginRestOutput* output,
                            const char* url,
-                           const OrthancPluginHttpRequest* request);
+                           const OrthancPluginHttpRequest* request,
+                           bool isThumbnail);
 
 void RetrieveSeriesRendered(OrthancPluginRestOutput* output,
                             const char* url,
-                            const OrthancPluginHttpRequest* request);
+                            const OrthancPluginHttpRequest* request,
+                            bool isThumbnail);
 
 void RetrieveStudyRendered(OrthancPluginRestOutput* output,
                            const char* url,
-                           const OrthancPluginHttpRequest* request);
+                           const OrthancPluginHttpRequest* request,
+                           bool isThumbnail);
 
 void SetPluginCanDownloadTranscodedFile(bool enable);
 
-void SetPluginCanUseExtendedFile(bool enable);
+void SetPluginCanUseExtendedFind(bool enable);
 
 void SetSystemIsReadOnly(bool isReadOnly);
\ No newline at end of file
